==> cost-interface-0.3.34-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/ChannelLaborPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.ChannelLaborRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 劳务支出登记详情信息
 * ChannelLaborDetail
 * 数据库表：channel_labor_detail
 */
public class ChannelLaborPayVo implements Serializable {

    private static final long serialVersionUID = -4133620249348850579L;
    private ChannelLaborRegistVo channelLaborRegistVo;
    /**
     * 
     * 表字段 : channel_labor_detail.id
     */
    private Integer id;
    
    /**
     * 酒店名称
     */
    private String fieldName;
    /**
     *  终端ID
     */
    private  String terminalId;
    /**
     * 终端名称
     */
    private String terminalName;
    /**
     * 数量
     */
    private Integer registNum;

    /**
     * 费用类型 编码
     */
    private String costTypeId;

    /**
     * 费用类型 名称
     */
    private String costTypeName;

    /**
     * 登记单号
     * 表字段 : channel_labor_detail.regist_no
     */
    private String registNo;
    /**
     * 行项目号
     */
    private Integer itemNo;

    /**
     * 促销员名称
     * 表字段 : channel_labor_detail.promotion_user
     */
    private String promotionUser;

    /**
     * 性别
     * 表字段 : channel_labor_detail.sex
     */
    private String sex;

    /**
     * 电话
     * 表字段 : channel_labor_detail.phone
     */
    private String phone;

    /**
     * 促销人员类型
     * 表字段 : channel_labor_detail.promotion_user_type
     */
    private String promotionUserType;

    /**
     * 开始时间
     * 表字段 : channel_labor_detail.begin_time
     */
    private Date sDate;

    /**
     * 结束时间
     * 表字段 : channel_labor_detail.end_time
     */
    private Date eDate;

    /**
     * 负责促销点名称
     * 表字段 : channel_labor_detail.promotion_location
     */
    private String promotionLocation;

    /**
     * 终端编码
     * 表字段 : channel_labor_detail.promotion_location_code
     */
    private String promotionLocationCode;

    /**
     * 省名称
     * 表字段 : channel_labor_detail.province
     */
    private String province;

    /**
     * 市名称
     * 表字段 : channel_labor_detail.city
     */
    private String city;

    /**
     * 区县名称
     * 表字段 : channel_labor_detail.county
     */
    private String county;

    /**
     * 详细地址
     * 表字段 : channel_labor_detail.detail_address
     */
    private String detailAddress;

    /**
     * 固定电话
     * 表字段 : channel_labor_detail.tel
     */
    private String tel;

    /**
     * 备注
     * 表字段 : channel_labor_detail.remarks
     */
    private String remarks;
    /**
     * 变更类型
     */
    private String changeType;

    /**
     * 
     * 表字段 : channel_labor_detail.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : channel_labor_detail.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : channel_labor_detail.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_date
     */
    private Date modifyDate;

    public ChannelLaborRegistVo getChannelLaborRegistVo() {
        return channelLaborRegistVo;
    }

    public void setChannelLaborRegistVo(ChannelLaborRegistVo channelLaborRegistVo) {
        this.channelLaborRegistVo = channelLaborRegistVo;
    }

    /**
     * 获取  字段:channel_labor_detail.id
     *
     * @return channel_labor_detail.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:channel_labor_detail.id
     *
     * @param id the value for channel_labor_detail.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 登记单号 字段:channel_labor_detail.regist_no
     *
     * @return channel_labor_detail.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:channel_labor_detail.regist_no
     *
     * @param registNo the value for channel_labor_detail.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 促销产品编码 字段:channel_labor_detail.promotion_user
     *
     * @return channel_labor_detail.promotion_user, 促销产品编码
     */
    public String getPromotionUser() {
        return promotionUser;
    }

    public String getFieldName() {
		return fieldName;
	}

	public void setFieldName(String fieldName) {
		this.fieldName = fieldName;
	}

	public String getTerminalId() {
		return terminalId;
	}

	public void setTerminalId(String terminalId) {
		this.terminalId = terminalId;
	}

	public String getTerminalName() {
		return terminalName;
	}

	public void setTerminalName(String terminalName) {
		this.terminalName = terminalName;
	}

	public Integer getRegistNum() {
		return registNum;
	}

	public void setRegistNum(Integer registNum) {
		this.registNum = registNum;
	}

	public static long getSerialversionuid() {
		return serialVersionUID;
	}

	/**
     * 设置 促销产品编码 字段:channel_labor_detail.promotion_user
     *
     * @param promotionUser the value for channel_labor_detail.promotion_user, 促销产品编码
     */
    public void setPromotionUser(String promotionUser) {
        this.promotionUser = promotionUser;
    }

    /**
     * 获取 性别 字段:channel_labor_detail.sex
     *
     * @return channel_labor_detail.sex, 性别
     */
    public String getSex() {
        return sex;
    }

    /**
     * 设置 性别 字段:channel_labor_detail.sex
     *
     * @param sex the value for channel_labor_detail.sex, 性别
     */
    public void setSex(String sex) {
        this.sex = sex;
    }

    /**
     * 获取 电话 字段:channel_labor_detail.phone
     *
     * @return channel_labor_detail.phone, 电话
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 设置 电话 字段:channel_labor_detail.phone
     *
     * @param phone the value for channel_labor_detail.phone, 电话
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }

    /**
     * 获取 促销人员类型 字段:channel_labor_detail.promotion_user_type
     *
     * @return channel_labor_detail.promotion_user_type, 促销人员类型
     */
    public String getPromotionUserType() {
        return promotionUserType;
    }

    /**
     * 设置 促销人员类型 字段:channel_labor_detail.promotion_user_type
     *
     * @param promotionUserType the value for channel_labor_detail.promotion_user_type, 促销人员类型
     */
    public void setPromotionUserType(String promotionUserType) {
        this.promotionUserType = promotionUserType;
    }

    public Integer getItemNo() {

        return id;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 负责促销点名称 字段:channel_labor_detail.promotion_location
     *
     * @return channel_labor_detail.promotion_location, 负责促销点名称
     */
    public String getPromotionLocation() {
        return promotionLocation;
    }

    /**
     * 设置 负责促销点名称 字段:channel_labor_detail.promotion_location
     *
     * @param promotionLocation the value for channel_labor_detail.promotion_location, 负责促销点名称
     */
    public void setPromotionLocation(String promotionLocation) {
        this.promotionLocation = promotionLocation;
    }

    /**
     * 获取 终端编码 字段:channel_labor_detail.promotion_location_code
     *
     * @return channel_labor_detail.promotion_location_code, 终端编码
     */
    public String getPromotionLocationCode() {
        return promotionLocationCode;
    }

    /**
     * 设置 终端编码 字段:channel_labor_detail.promotion_location_code
     *
     * @param promotionLocationCode the value for channel_labor_detail.promotion_location_code, 终端编码
     */
    public void setPromotionLocationCode(String promotionLocationCode) {
        this.promotionLocationCode = promotionLocationCode;
    }

    /**
     * 获取 省名称 字段:channel_labor_detail.province
     *
     * @return channel_labor_detail.province, 省名称
     */
    public String getProvince() {
        return province;
    }

    /**
     * 设置 省名称 字段:channel_labor_detail.province
     *
     * @param province the value for channel_labor_detail.province, 省名称
     */
    public void setProvince(String province) {
        this.province = province;
    }

    /**
     * 获取 市名称 字段:channel_labor_detail.city
     *
     * @return channel_labor_detail.city, 市名称
     */
    public String getCity() {
        return city;
    }

    /**
     * 设置 市名称 字段:channel_labor_detail.city
     *
     * @param city the value for channel_labor_detail.city, 市名称
     */
    public void setCity(String city) {
        this.city = city;
    }

    /**
     * 获取 区县名称 字段:channel_labor_detail.county
     *
     * @return channel_labor_detail.county, 区县名称
     */
    public String getCounty() {
        return county;
    }

    /**
     * 设置 区县名称 字段:channel_labor_detail.county
     *
     * @param county the value for channel_labor_detail.county, 区县名称
     */
    public void setCounty(String county) {
        this.county = county;
    }

    /**
     * 获取 详细地址 字段:channel_labor_detail.detail_address
     *
     * @return channel_labor_detail.detail_address, 详细地址
     */
    public String getDetailAddress() {
        return detailAddress;
    }

    /**
     * 设置 详细地址 字段:channel_labor_detail.detail_address
     *
     * @param detailAddress the value for channel_labor_detail.detail_address, 详细地址
     */
    public void setDetailAddress(String detailAddress) {
        this.detailAddress = detailAddress;
    }

    /**
     * 获取 固定电话 字段:channel_labor_detail.tel
     *
     * @return channel_labor_detail.tel, 固定电话
     */
    public String getTel() {
        return tel;
    }

    /**
     * 设置 固定电话 字段:channel_labor_detail.tel
     *
     * @param tel the value for channel_labor_detail.tel, 固定电话
     */
    public void setTel(String tel) {
        this.tel = tel;
    }

    /**
     * 获取 备注 字段:channel_labor_detail.remarks
     *
     * @return channel_labor_detail.remarks, 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 设置 备注 字段:channel_labor_detail.remarks
     *
     * @param remarks the value for channel_labor_detail.remarks, 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }

    /**
     * 获取  字段:channel_labor_detail.create_id
     *
     * @return channel_labor_detail.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:channel_labor_detail.create_id
     *
     * @param createId the value for channel_labor_detail.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:channel_labor_detail.create_name
     *
     * @return channel_labor_detail.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:channel_labor_detail.create_name
     *
     * @param createName the value for channel_labor_detail.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:channel_labor_detail.create_date
     *
     * @return channel_labor_detail.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:channel_labor_detail.create_date
     *
     * @param createDate the value for channel_labor_detail.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_id
     *
     * @return channel_labor_detail.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_id
     *
     * @param modifyId the value for channel_labor_detail.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_name
     *
     * @return channel_labor_detail.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_name
     *
     * @param modifyName the value for channel_labor_detail.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_date
     *
     * @return channel_labor_detail.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_date
     *
     * @param modifyDate the value for channel_labor_detail.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
}

==> cost-interface-0.3.46-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/ChannelLaborPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.ChannelLaborRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 劳务支出登记详情信息
 * ChannelLaborDetail
 * 数据库表：channel_labor_detail
 */
public class ChannelLaborPayVo implements Serializable {

    private static final long serialVersionUID = -4133620249348850579L;
    private ChannelLaborRegistVo registVo;
    /**
     * 
     * 表字段 : channel_labor_detail.id
     */
    private Integer id;
    
    /**
     * 酒店名称
     */
    private String fieldName;
    /**
     *  终端ID
     */
    private  String terminalId;
    /**
     * 终端名称
     */
    private String terminalName;
    /**
     * 数量
     */
    private Integer registNum;

    /**
     * 费用类型 编码
     */
    private String costTypeId;

    /**
     * 费用类型 名称
     */
    private String costTypeName;

    /**
     * 登记单号
     * 表字段 : channel_labor_detail.regist_no
     */
    private String registNo;
    /**
     * 行项目号
     */
    private Integer itemNo;

    /**
     * 促销员名称
     * 表字段 : channel_labor_detail.promotion_user
     */
    private String promotionUser;

    /**
     * 性别
     * 表字段 : channel_labor_detail.sex
     */
    private String sex;

    /**
     * 电话
     * 表字段 : channel_labor_detail.phone
     */
    private String phone;

    /**
     * 促销人员类型
     * 表字段 : channel_labor_detail.promotion_user_type
     */
    private String promotionUserType;

    /**
     * 开始时间
     * 表字段 : channel_labor_detail.begin_time
     */
    private Date sDate;

    /**
     * 结束时间
     * 表字段 : channel_labor_detail.end_time
     */
    private Date eDate;

    /**
     * 负责促销点名称
     * 表字段 : channel_labor_detail.promotion_location
     */
    private String promotionLocation;

    /**
     * 终端编码
     * 表字段 : channel_labor_detail.promotion_location_code
     */
    private String promotionLocationCode;

    /**
     * 省名称
     * 表字段 : channel_labor_detail.province
     */
    private String province;

    /**
     * 市名称
     * 表字段 : channel_labor_detail.city
     */
    private String city;

    /**
     * 区县名称
     * 表字段 : channel_labor_detail.county
     */
    private String county;

    /**
     * 详细地址
     * 表字段 : channel_labor_detail.detail_address
     */
    private String detailAddress;

    /**
     * 固定电话
     * 表字段 : channel_labor_detail.tel
     */
    private String tel;

    /**
     * 备注
     * 表字段 : channel_labor_detail.remarks
     */
    private String remarks;
    /**
     * 变更类型
     */
    private String changeType;

    /**
     * 
     * 表字段 : channel_labor_detail.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : channel_labor_detail.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : channel_labor_detail.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : channel_labor_detail.modify_date
     */
    private Date modifyDate;

    public ChannelLaborRegistVo getRegistVo() {
        return registVo;
    }

    public void setRegistVo(ChannelLaborRegistVo registVo) {
        this.registVo = registVo;
    }

    /**
     * 获取  字段:channel_labor_detail.id
     *
     * @return channel_labor_detail.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:channel_labor_detail.id
     *
     * @param id the value for channel_labor_detail.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 登记单号 字段:channel_labor_detail.regist_no
     *
     * @return channel_labor_detail.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:channel_labor_detail.regist_no
     *
     * @param registNo the value for channel_labor_detail.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 促销产品编码 字段:channel_labor_detail.promotion_user
     *
     * @return channel_labor_detail.promotion_user, 促销产品编码
     */
    public String getPromotionUser() {
        return promotionUser;
    }

    public String getFieldName() {
		return fieldName;
	}

	public void setFieldName(String fieldName) {
		this.fieldName = fieldName;
	}

	public String getTerminalId() {
		return terminalId;
	}

	public void setTerminalId(String terminalId) {
		this.terminalId = terminalId;
	}

	public String getTerminalName() {
		return terminalName;
	}

	public void setTerminalName(String terminalName) {
		this.terminalName = terminalName;
	}

	public Integer getRegistNum() {
		return registNum;
	}

	public void setRegistNum(Integer registNum) {
		this.registNum = registNum;
	}

	public static long getSerialversionuid() {
		return serialVersionUID;
	}

	/**
     * 设置 促销产品编码 字段:channel_labor_detail.promotion_user
     *
     * @param promotionUser the value for channel_labor_detail.promotion_user, 促销产品编码
     */
    public void setPromotionUser(String promotionUser) {
        this.promotionUser = promotionUser;
    }

    /**
     * 获取 性别 字段:channel_labor_detail.sex
     *
     * @return channel_labor_detail.sex, 性别
     */
    public String getSex() {
        return sex;
    }

    /**
     * 设置 性别 字段:channel_labor_detail.sex
     *
     * @param sex the value for channel_labor_detail.sex, 性别
     */
    public void setSex(String sex) {
        this.sex = sex;
    }

    /**
     * 获取 电话 字段:channel_labor_detail.phone
     *
     * @return channel_labor_detail.phone, 电话
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 设置 电话 字段:channel_labor_detail.phone
     *
     * @param phone the value for channel_labor_detail.phone, 电话
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }

    /**
     * 获取 促销人员类型 字段:channel_labor_detail.promotion_user_type
     *
     * @return channel_labor_detail.promotion_user_type, 促销人员类型
     */
    public String getPromotionUserType() {
        return promotionUserType;
    }

    /**
     * 设置 促销人员类型 字段:channel_labor_detail.promotion_user_type
     *
     * @param promotionUserType the value for channel_labor_detail.promotion_user_type, 促销人员类型
     */
    public void setPromotionUserType(String promotionUserType) {
        this.promotionUserType = promotionUserType;
    }

    public Integer getItemNo() {

        return id;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 负责促销点名称 字段:channel_labor_detail.promotion_location
     *
     * @return channel_labor_detail.promotion_location, 负责促销点名称
     */
    public String getPromotionLocation() {
        return promotionLocation;
    }

    /**
     * 设置 负责促销点名称 字段:channel_labor_detail.promotion_location
     *
     * @param promotionLocation the value for channel_labor_detail.promotion_location, 负责促销点名称
     */
    public void setPromotionLocation(String promotionLocation) {
        this.promotionLocation = promotionLocation;
    }

    /**
     * 获取 终端编码 字段:channel_labor_detail.promotion_location_code
     *
     * @return channel_labor_detail.promotion_location_code, 终端编码
     */
    public String getPromotionLocationCode() {
        return promotionLocationCode;
    }

    /**
     * 设置 终端编码 字段:channel_labor_detail.promotion_location_code
     *
     * @param promotionLocationCode the value for channel_labor_detail.promotion_location_code, 终端编码
     */
    public void setPromotionLocationCode(String promotionLocationCode) {
        this.promotionLocationCode = promotionLocationCode;
    }

    /**
     * 获取 省名称 字段:channel_labor_detail.province
     *
     * @return channel_labor_detail.province, 省名称
     */
    public String getProvince() {
        return province;
    }

    /**
     * 设置 省名称 字段:channel_labor_detail.province
     *
     * @param province the value for channel_labor_detail.province, 省名称
     */
    public void setProvince(String province) {
        this.province = province;
    }

    /**
     * 获取 市名称 字段:channel_labor_detail.city
     *
     * @return channel_labor_detail.city, 市名称
     */
    public String getCity() {
        return city;
    }

    /**
     * 设置 市名称 字段:channel_labor_detail.city
     *
     * @param city the value for channel_labor_detail.city, 市名称
     */
    public void setCity(String city) {
        this.city = city;
    }

    /**
     * 获取 区县名称 字段:channel_labor_detail.county
     *
     * @return channel_labor_detail.county, 区县名称
     */
    public String getCounty() {
        return county;
    }

    /**
     * 设置 区县名称 字段:channel_labor_detail.county
     *
     * @param county the value for channel_labor_detail.county, 区县名称
     */
    public void setCounty(String county) {
        this.county = county;
    }

    /**
     * 获取 详细地址 字段:channel_labor_detail.detail_address
     *
     * @return channel_labor_detail.detail_address, 详细地址
     */
    public String getDetailAddress() {
        return detailAddress;
    }

    /**
     * 设置 详细地址 字段:channel_labor_detail.detail_address
     *
     * @param detailAddress the value for channel_labor_detail.detail_address, 详细地址
     */
    public void setDetailAddress(String detailAddress) {
        this.detailAddress = detailAddress;
    }

    /**
     * 获取 固定电话 字段:channel_labor_detail.tel
     *
     * @return channel_labor_detail.tel, 固定电话
     */
    public String getTel() {
        return tel;
    }

    /**
     * 设置 固定电话 字段:channel_labor_detail.tel
     *
     * @param tel the value for channel_labor_detail.tel, 固定电话
     */
    public void setTel(String tel) {
        this.tel = tel;
    }

    /**
     * 获取 备注 字段:channel_labor_detail.remarks
     *
     * @return channel_labor_detail.remarks, 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 设置 备注 字段:channel_labor_detail.remarks
     *
     * @param remarks the value for channel_labor_detail.remarks, 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }

    /**
     * 获取  字段:channel_labor_detail.create_id
     *
     * @return channel_labor_detail.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:channel_labor_detail.create_id
     *
     * @param createId the value for channel_labor_detail.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:channel_labor_detail.create_name
     *
     * @return channel_labor_detail.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:channel_labor_detail.create_name
     *
     * @param createName the value for channel_labor_detail.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:channel_labor_detail.create_date
     *
     * @return channel_labor_detail.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:channel_labor_detail.create_date
     *
     * @param createDate the value for channel_labor_detail.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_id
     *
     * @return channel_labor_detail.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_id
     *
     * @param modifyId the value for channel_labor_detail.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_name
     *
     * @return channel_labor_detail.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_name
     *
     * @param modifyName the value for channel_labor_detail.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:channel_labor_detail.modify_date
     *
     * @return channel_labor_detail.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:channel_labor_detail.modify_date
     *
     * @param modifyDate the value for channel_labor_detail.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
}
